@@ -22,7 +22,6 @@
 
 #include "ksudoku_logging.h"
 
-#include <QDebug>
 #include <QGraphicsPixmapItem>
 #include <QGraphicsSceneEvent>
 
@@ -196,7 +195,7 @@ GroupGraphicsItem::GroupGraphicsItem(const QVector<QPoint> &cells, bool isCage)
 	m_borderVisible = true;
 	
 	setEnabled(false);
-	setAcceptedMouseButtons(0);
+    setAcceptedMouseButtons(Qt::NoButton);
 	
 	detectType();
 	if (isCage) {
